#define SUCCESS            0
#define FILE_ERR           1
#define FILE_NOT_FOUND     2
#define FILE_NOT_WRITEABLE 3
#define SEED_ERR           4

int wipe_file(char *filename, int verbose, int wipe_mode);

